# Yardstiq (ys)

Quantum Benchmarking CLI and extensible tool.

## Installation

```bash
pip install yardstiq yardstiq-default
```

```bash
ys --help

ys qpu ls

ys benchmark run vqe --qpu=local/qiskit-aer
```